@@ -89,31 +89,34 @@ end
 -- If the user's home directory cannot be read, nil is returned.
 function compact_path (path)
   local home = posix.getpasswd (nil, "dir")
-  -- If we cannot get the home directory, return error
+  -- If we cannot get the home directory, return empty string
   if home == nil then
-    return nil
+    return ""
   end
 
-  -- Replace `^/$HOME' (if found) with `~'.
+  -- Replace `^$HOME' (if found) with `~'.
   return string.gsub (path, "^" .. home, "~")
 end
 
 Defun ("find-file",
-       {},
+       {"string"},
 [[
 Edit the specified file.
 Switch to a buffer visiting the file,
 creating one if none already exists.
 ]],
   true,
-  function ()
-    local ms = minibuf_read_filename ("Find file: ", cur_bp.dir)
+  function (filename)
     local ok = leNIL
 
-    if not ms then
+    if not filename then
+      filename = minibuf_read_filename ("Find file: ", cur_bp.dir)
+    end
+
+    if not filename then
       ok = execute_function ("keyboard-quit")
-    elseif ms ~= "" then
-      ok = bool_to_lisp (find_file (ms))
+    elseif "" ~= filename then
+      ok = find_file (filename)
     end
 
     return ok
@@ -121,15 +124,15 @@ creating one if none already exists.
 )
 
 Defun ("find-file-read-only",
-       {},
+       {"string"},
 [[
 Edit the specified file but don't allow changes.
 Like `find-file' but marks buffer as read-only.
 Use @kbd{M-x toggle-read-only} to permit editing.
 ]],
   true,
-  function ()
-    local ok = excecute_function ("find-file")
+  function (filename)
+    local ok = execute_function ("find-file", filename)
     if ok == leT then
       cur_bp.readonly = true
     end
@@ -227,7 +230,7 @@ Set mark after the inserted text.
 -- Write buffer to given file name with given mode.
 local function raw_write_to_disk (bp, filename, mode)
   local ret = true
-  local h = io.open (filename, "w") -- FIXME: use posix.open, and use mode
+  local h = posix.creat (filename, mode)
 
   if not h then
     return false
@@ -236,13 +239,13 @@ local function raw_write_to_disk (bp, filename, mode)
   -- Save the lines.
   local lp = bp.lines.next
   while lp ~= bp.lines do
-    if not h:write (lp.text) then
+    if not posix.write (h, lp.text) then
       ret = false
       break
     end
 
     if lp.next ~= bp.lines then
-      if not h:write (bp.eol) then
+      if not posix.write (h, bp.eol) then
         ret = false
         break
       end
@@ -251,7 +254,7 @@ local function raw_write_to_disk (bp, filename, mode)
     lp = lp.next
   end
 
-  if not h:close () then
+  if posix.close (h) ~= 0 then
     ret = false
   end
 
@@ -295,11 +298,10 @@ local function copy_file (source, dest)
     minibuf_error (string.format ("%s: unable to create backup", dest))
     return false
   end
-  ofd = posix.fdopen (ofd, "w") -- FIXME: Implement and use posix.write
 
-  local written = ofd:write (ifd:read ("*a"))
+  local written = posix.write (ofd, ifd:read ("*a"))
   ifd:close ()
-  ofd:close ()
+  posix.close (ofd)
 
   if not written then
     minibuf_error (string.format ("Unable to write to backup file `%s'", dest))
@@ -349,7 +351,7 @@ local function write_to_disk (bp, filename)
         bp.backup = true
       else
         minibuf_error (string.format ("Cannot make backup file: %s", posix.errno ()))
-        waitkey (WAITKEY_DEFAULT)
+        waitkey ()
       end
     end
   end
@@ -445,7 +447,7 @@ Interactively, confirmation is required unless you supply a prefix argument.
   true,
   function ()
     return write_buffer (cur_bp, true,
-                         interactive and not lastflag.set_uniarg,
+                         _interactive and not lastflag.set_uniarg,
                          nil, "Write file: ")
   end
 )
@@ -465,7 +467,7 @@ local function save_some_buffers ()
       else
         while true do
           minibuf_write (string.format ("Save file %s? (y, n, !, ., q) ", fname))
-          local c = getkey ()
+          local c = getkey (GETKEY_DEFAULT)
           minibuf_clear ()
 
           if c == KBD_CANCEL then -- C-g
@@ -548,7 +550,7 @@ Make DIR become the current buffer's default directory.
 ]],
   true,
   function (dir)
-    if not dir and interactive then
+    if not dir and _interactive then
       dir = minibuf_read_filename ("Change default directory: ", cur_bp.dir)
     end
 
@@ -558,7 +560,7 @@ Make DIR become the current buffer's default directory.
 
     if dir ~= "" then
       local st = posix.stat (dir)
-      if not s or not s.type == "directory" then
+      if not st or not st.type == "directory" then
         minibuf_error (string.format ("`%s' is not a directory", dir))
       elseif posix.chdir (dir) == -1 then
         minibuf_write (string.format ("%s: %s", dir, posix.errno ()))
