@@ -43,25 +43,6 @@ Stop Zile and return to superior process.
   end
 )
 
-Defun ("overwrite-mode",
-       {"number"},
-[[
-Toggle overwrite mode.
-With prefix argument @i{arg}, turn overwrite mode on if @i{arg} is positive,
-otherwise turn it off.  In overwrite mode, printing characters typed
-in replace existing text on a one-for-one basis, rather than pushing
-it to the right.  At the end of a line, such characters extend the line.
-Before a tab, such characters insert until the tab is filled in.
-@kbd{C-q} still inserts characters in overwrite mode; this
-is supposed to make it easier to insert characters when necessary.
-]],
-  true,
-  function (arg)
-    cur_bp.overwrite = arg and arg > 0 or not cur_bp.overwrite
-    return true
-  end
-)
-
 Defun ("toggle-read-only",
        {},
 [[
@@ -101,34 +82,8 @@ Put the mark where point is now, and point where the mark is now.
     local tmp = table.clone (cur_bp.pt)
     cur_bp.pt = table.clone (cur_bp.mark.pt)
     cur_bp.mark.pt = tmp
-
-    -- In transient-mark-mode we must reactivate the mark.
-    if get_variable_bool ("transient-mark-mode") then
-      activate_mark ()
-    end
-
-    thisflag.need_resync = true
-  end
-)
-
-Defun ("transient-mark-mode",
-       {"number"},
-[[
-Toggle Transient Mark mode.
-With arg, turn Transient Mark mode on if arg is positive, off otherwise.
-]],
-  true,
-  function (n)
-    if not n and not lastflag.set_uniarg then
-      set_variable ("transient-mark-mode", get_variable_bool ("transient-mark-mode") and "nil" or "t")
-    elseif not n then
-      n = current_prefix_arg
-    end
-    if n then
-      set_variable ("transient-mark-mode", n > 0 and "t" or "nil")
-    end
-
     activate_mark ()
+    thisflag.need_resync = true
   end
 )
 
@@ -218,10 +173,10 @@ by 4 each time.
         thisflag.uniarg_empty = false
 
         if bit.band (key, KBD_META) ~= 0 then
-          as = "ESC"
+          as = "ESC "
         end
 
-        as = as .. string.format (" %d", digit)
+        as = as .. string.format ("%d", digit)
 
         if i == 0 then
           arg = digit
@@ -237,10 +192,10 @@ by 4 each time.
         else
           break
         end
-      elseif key == string.byte ('-') and i == 0 then
+      elseif key == bit.bor (KBD_META, string.byte ('-')) and i == 0 then
         if sgn > 0 then
           sgn = -sgn
-          as = as .. " -"
+          as = as .. "-"
           -- The default negative arg is -1, not -4.
           arg = 1
           thisflag.uniarg_empty = false
@@ -357,7 +312,7 @@ Just C-u as argument means to use the current column.
 ]],
   true,
   function (n)
-    if not n and interactive then
+    if not n and _interactive then
       if lastflag.set_uniarg then
         n = current_prefix_arg
       else
@@ -390,8 +345,8 @@ This is useful for inserting control characters.
   true,
   function ()
     minibuf_write ("C-q-")
-    local c = xgetkey (GETKEY_UNFILTERED, 0)
-    insert_char_in_insert_mode (string.char (c))
+    local c = getkey_unfiltered (GETKEY_DEFAULT)
+    insert_char (string.char (c))
     minibuf_clear ()
   end
 )
@@ -932,148 +887,6 @@ Put point at beginning and mark at end of buffer.
   end
 )
 
-
--- Compact the spaces into tabulations according to the `tw' tab width.
-local function tabify_string (src, scol, tw)
-  local dest = ""
-  local dcol = scol
-
-  for i = 1, #src do
-    if src[i] == ' ' then
-      dcol = dcol + 1
-    elseif src[i] == '\t' then
-      dcol = dcol + tw
-      dcol = dcol - dcol % tw
-    else
-      while ((scol + tw) - (scol + tw) % tw) <= dcol and scol ~= dcol - 1 do
-        dest = dest .. '\t'
-        scol = scol + tw
-        scol = scol - scol % tw
-      end
-      while scol < dcol do
-        dest = dest .. ' '
-        scol = scol + 1
-      end
-      dest = dest .. src[i]
-      scol = scol + 1
-      dcol = dcol + 1
-    end
-  end
-
-  return dest
-end
-
--- Expand the tabulations into spaces according to the `tw' tab width.
--- The output buffer should be big enough to contain the expanded string,
--- i.e. strlen (src) * tw + 1.
-local function untabify_string (src, scol, tw)
-  local col = scol
-  local dest = ""
-
-  for i = 1, #src do
-    if src[i] == '\t' then
-      repeat
-        dest = dest .. ' '
-        col = col + 1
-      until col % tw == 0
-    else
-      dest = dest .. src[i]
-      col = col + 1
-    end
-  end
-
-  return dest
-end
-
-local function edit_tab_line (lp, lineno, offset, size, action)
-  if size == 0 then
-    return
-  end
-
-  -- Get offset's column.
-  local t = tab_width (cur_bp)
-  local col = 0
-  for i = 1, offset do
-    if lp.text[i] == '\t' then
-      col = bit.bor (col, t - 1)
-    end
-    col = col + 1
-  end
-
-  -- Call un/tabify function.
-  local src = string.sub (lp.text, offset + 1, offset + size)
-  local dest = action (src, col, t)
-  if src ~= dest then
-    undo_save (UNDO_REPLACE_BLOCK, make_point (lineno, offset), size, #dest)
-    line_replace_text (lp, offset, size, dest, false)
-  end
-end
-
-function edit_tab_region (action)
-  local rp = region_new ()
-
-  if warn_if_readonly_buffer () or not calculate_the_region (rp) then
-    return leNIL
-  end
-
-  if rp.size ~= 0 then
-    local m = point_marker ()
-
-    undo_save (UNDO_START_SEQUENCE, m.pt, 0, 0)
-    local lp = rp.start.p
-    for lineno = rp.start.n, rp.finish.n do
-      -- First line.
-      if lineno == rp.start.n then
-        if lineno == rp.finish.n then -- Region on a sole line.
-          edit_tab_line (lp, lineno, rp.start.o, rp.size, action)
-        else -- Region is multi-line.
-          edit_tab_line (lp, lineno, rp.start.o, #lp.text - rp.start.o, action)
-        end
-      elseif lineno == rp.finish.n then -- Last line of multi-line region.
-        edit_tab_line (lp, lineno, 0, rp.finish.o, action)
-      else -- Middle line of multi-line region.
-        edit_tab_line (lp, lineno, 0, #lp.text, action)
-      end
-      if lineno == rp.finish.n then -- Done?
-        break
-      end
-      lp = lp.next
-    end
-    cur_bp.pt = table.clone (m.pt)
-    undo_save (UNDO_END_SEQUENCE, m.pt, 0, 0)
-    unchain_marker (m)
-    deactivate_mark ()
-  end
-
-  return leT
-end
-
-Defun ("tabify",
-       {},
-[[
-Convert multiple spaces in region to tabs when possible.
-A group of spaces is partially replaced by tabs
-when this can be done without changing the column they end at.
-The variable @samp{tab-width} controls the spacing of tab stops.
-]],
-  true,
-  function ()
-    return edit_tab_region (tabify_string)
-  end
-)
-
-Defun ("untabify",
-       {},
-[[
-Convert all tabs in region to multiple spaces, preserving columns.
-The variable @samp{tab-width} controls the spacing of tab stops.
-]],
-  true,
-  function ()
-    return edit_tab_region (untabify_string)
-  end
-)
-
 Defun ("back-to-indentation",
        {},
 [[
